@@ -96,7 +96,11 @@ pg_rage_terminator_main(Datum main_arg)
 	BackgroundWorkerUnblockSignals();
 
 	/* Connect to a database */
+#if PG_VERSION_NUM >= 110000
+	BackgroundWorkerInitializeConnection("postgres", NULL, BGWORKER_SHMEM_ACCESS|BGWORKER_BACKEND_DATABASE_CONNECTION);
+#else
 	BackgroundWorkerInitializeConnection("postgres", NULL);
+#endif
 
 	/* Build query for process */
 	initStringInfo(&buf);
